@@ -49,7 +49,10 @@
 //!
 // FIXME: We might be able to improve the interface when `ComptimeVec` is not
 // restricted to "comptime" anymore
-use core::ops::{Deref, DerefMut, Index, IndexMut};
+use core::{
+    marker::Destruct,
+    ops::{Deref, DerefMut, Index, IndexMut},
+};
 
 use super::{BindBorrowType, BindUsage};
 use crate::utils::{
@@ -378,17 +381,16 @@ pub(super) const fn sort_bindings<Callback, SorterUseInfoList, VertexList>(
                     SuccessorIterState::BindInitToBorrowingUser(bind_i, bind_user_i) => {
                         let cb = self.cb.borrow();
                         let bind_users = cb.bind_users(bind_i);
-                        // `[T]::get` is not `const fn` yet [ref:const_slice_get]
-                        if bind_user_i < bind_users.len() {
+                        if let Some(bind_user) = bind_users.get(bind_user_i) {
                             self.st = SuccessorIterState::BindInitToBorrowingUser(
                                 bind_i,
                                 bind_user_i + 1,
                             );
                             if matches!(
-                                bind_users[bind_user_i].1,
+                                bind_user.1,
                                 BindBorrowType::Borrow | BindBorrowType::BorrowMut
                             ) {
-                                return Some(match bind_users[bind_user_i].0 {
+                                return Some(match bind_user.0 {
                                     BindUsage::Executable => Vertex::Executable,
                                     BindUsage::Bind(user_bind_i) => Vertex::BindInit(user_bind_i),
                                 });
@@ -434,17 +436,16 @@ pub(super) const fn sort_bindings<Callback, SorterUseInfoList, VertexList>(
                     SuccessorIterState::BindDisownToTakingUser(bind_i, bind_user_i) => {
                         let cb = self.cb.borrow();
                         let bind_users = cb.bind_users(bind_i);
-                        // `[T]::get` is not `const fn` yet [ref:const_slice_get]
-                        if bind_user_i < bind_users.len() {
+                        if let Some(bind_user) = bind_users.get(bind_user_i) {
                             self.st =
                                 SuccessorIterState::BindDisownToTakingUser(bind_i, bind_user_i + 1);
                             if matches!(
-                                bind_users[bind_user_i].1,
+                                bind_user.1,
                                 BindBorrowType::Take
                                     | BindBorrowType::TakeRef
                                     | BindBorrowType::TakeMut
                             ) {
-                                return Some(match bind_users[bind_user_i].0 {
+                                return Some(match bind_user.0 {
                                     BindUsage::Executable => Vertex::Executable,
                                     BindUsage::Bind(user_bind_i) => Vertex::BindInit(user_bind_i),
                                 });
@@ -540,12 +541,12 @@ trait MyIterator {
 }
 
 trait GraphAccess<VertexRef> {
-    type VertexIter<'a>: ~const MyIterator<Item = VertexRef> + ~const Drop + 'a
+    type VertexIter<'a>: ~const MyIterator<Item = VertexRef> + ~const Destruct + 'a
     where
         Self: 'a;
     fn vertices(&self) -> Self::VertexIter<'_>;
 
-    type SuccessorIter<'a>: ~const MyIterator<Item = VertexRef> + ~const Drop + 'a
+    type SuccessorIter<'a>: ~const MyIterator<Item = VertexRef> + ~const Destruct + 'a
     where
         Self: 'a;
     fn successors(&self, v: &VertexRef) -> Self::SuccessorIter<'_>;
@@ -599,9 +600,9 @@ const fn topological_sort<
 where
     Graph: ~const GraphAccess<VertexRef>,
     // [ref:const_trait_not_implied] necessitates `: ~const MyIterator`
-    Graph::VertexIter<'a>: ~const MyIterator + ~const Drop,
+    Graph::VertexIter<'a>: ~const MyIterator + ~const Destruct,
     // [ref:const_trait_not_implied] necessitates `: ~const MyIterator`
-    Graph::SuccessorIter<'a>: ~const MyIterator + ~const Drop,
+    Graph::SuccessorIter<'a>: ~const MyIterator + ~const Destruct,
     VertexRef: Copy,
     VertexRefLessThan: ~const FnMut(&VertexRef, &VertexRef) -> bool,
     // `~const Deref[Mut]` isn't implied because of
